BoardLayoutValidationError

Enum BoardLayoutValidationError 

pub enum BoardLayoutValidationError {
Show 14 variants UnsupportedSchema { found: String, expected: &'static str, }, EmptyName, InvalidPitch { pitch_mm: f32, }, InvalidRows { rows: usize, }, InvalidLongRowCols { long_row_cols: usize, }, InvalidLongRowColsForRows { rows: usize, long_row_cols: usize, }, InvalidOuterRadius { marker_outer_radius_mm: f32, }, InvalidInnerRadius { marker_inner_radius_mm: f32, }, InvalidRingWidth { marker_ring_width_mm: f32, }, InnerRadiusNotSmallerThanOuter { marker_inner_radius_mm: f32, marker_outer_radius_mm: f32, }, NonPositiveCodeBandGap { inner_ring_outer_edge_mm: f32, outer_ring_inner_edge_mm: f32, }, OuterDiameterExceedsMinCenterSpacing { marker_outer_diameter_mm: f32, min_center_spacing_mm: f32, }, MarkerDrawDiameterExceedsMinCenterSpacing { marker_draw_diameter_mm: f32, min_center_spacing_mm: f32, }, DerivedZeroColumns { row_index: usize, rows: usize, long_row_cols: usize, },
}
Validation failures for a board layout specification.

Variants



UnsupportedSchema

Validation failed: unsupported target schema version.

Fields

found: String

Schema string found in the file.

expected: &'static str

Schema string the loader expected.



EmptyName

Validation failed: target name is empty.



InvalidPitch

Validation failed: pitch is non-positive or non-finite.

Fields

pitch_mm: f32

The invalid pitch value.



InvalidRows

Validation failed: row count is zero.

Fields

rows: usize

The invalid row count.



InvalidLongRowCols

Validation failed: long-row column count is zero.

Fields

long_row_cols: usize

The invalid column count.



InvalidLongRowColsForRows

Validation failed: long-row columns must exceed short-row columns derived from row count.

Fields

rows: usize

Total number of rows.

long_row_cols: usize

Column count for the longest row.



InvalidOuterRadius

Validation failed: outer radius is non-positive or non-finite.

Fields

marker_outer_radius_mm: f32

The invalid outer radius value.



InvalidInnerRadius

Validation failed: inner radius is non-positive or non-finite.

Fields

marker_inner_radius_mm: f32

The invalid inner radius value.



InvalidRingWidth

Validation failed: ring width is non-positive or non-finite.

Fields

marker_ring_width_mm: f32

The invalid ring width value.



InnerRadiusNotSmallerThanOuter

Validation failed: inner radius must be strictly less than outer radius.

Fields

marker_inner_radius_mm: f32

The inner radius value.

marker_outer_radius_mm: f32

The outer radius value.



NonPositiveCodeBandGap

Validation failed: code band gap between inner and outer rings is non-positive.

Fields

inner_ring_outer_edge_mm: f32

Outer edge of the inner ring in mm.

outer_ring_inner_edge_mm: f32

Inner edge of the outer ring in mm.



OuterDiameterExceedsMinCenterSpacing

Validation failed: outer diameter exceeds minimum center-to-center spacing.

Fields

marker_outer_diameter_mm: f32

Outer diameter in mm.

min_center_spacing_mm: f32

Minimum center spacing in mm.



MarkerDrawDiameterExceedsMinCenterSpacing

Validation failed: marker draw diameter exceeds minimum center-to-center spacing.

Fields

marker_draw_diameter_mm: f32

Marker draw diameter in mm.

min_center_spacing_mm: f32

Minimum center spacing in mm.



DerivedZeroColumns

Validation failed: a row has zero columns after applying hex-lattice offset.

Fields

row_index: usize

Index of the problematic row.

rows: usize

Total number of rows.

long_row_cols: usize

Column count for the longest row.